==> touhoulittlemaid-fabric-1.21.1-0.0.7-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemCamera.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import com.github.tartaricacid.touhoulittlemaid.advancements.maid.TriggerType;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.*;
import com.github.tartaricacid.touhoulittlemaid.util.MaidRayTraceHelper;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import net.minecraft.class_124;
import net.minecraft.class_1264;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1271;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_7923;
import net.minecraft.class_9279;

public class ItemCamera extends class_1792 {
    public ItemCamera() {
        super((new class_1793()).method_7889(1).method_7895(50));
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 worldIn, class_1657 playerIn, class_1268 handIn) {
        if (handIn == class_1268.field_5808) {
            int searchDistance = 8;
            class_1799 camera = playerIn.method_5998(handIn);
            Optional<EntityMaid> result = MaidRayTraceHelper.rayTraceMaid(playerIn, searchDistance);
            if (result.isPresent()) {
                EntityMaid maid = result.get();
                if (!worldIn.field_9236 && maid.method_5805() && maid.method_6171(playerIn) && !maid.method_6113()) {
                    spawnMaidPhoto(worldIn, maid, playerIn);
                    maid.method_31472();
                    playerIn.method_7357().method_7906(this, 20);
                    camera.method_7970(1, playerIn, class_1304.field_6173);
                    if (playerIn instanceof class_3222 serverPlayer) {
                        InitTrigger.MAID_EVENT.trigger(serverPlayer, TriggerType.PHOTO_MAID);
                    }
                }
                maid.spawnExplosionParticle();
                playerIn.method_5783(InitSounds.CAMERA_USE, 1.0f, 1.0f);
                return class_1271.method_29237(camera, worldIn.field_9236);
            }
        }
        return super.method_7836(worldIn, playerIn, handIn);
    }

    private void spawnMaidPhoto(class_1937 worldIn, EntityMaid maid, class_1657 playerIn) {
        class_1799 photo = InitItems.PHOTO.method_7854();
        class_2487 maidTag = new class_2487();
        maid.setHomeModeEnable(false);
        maid.method_5647(maidTag);
        maidTag.method_10582("id", Objects.requireNonNull(class_7923.field_41177.method_10221(InitEntities.MAID)).toString());
        photo.method_57379(InitDataComponent.MAID_INFO, class_9279.method_57456(maidTag));
        class_1264.method_5449(worldIn, playerIn.method_23317(), playerIn.method_23318(), playerIn.method_23321(), photo);
    }

    @Override
    public class_1269 method_7847(class_1799 stack, class_1657 playerIn, class_1309 target, class_1268 hand) {
        // 返回 true，阻止打开女仆 GUI
        if (stack.method_7909() == this && target.method_5805() && target instanceof EntityMaid && ((EntityMaid) target).method_6171(playerIn)) {
            this.method_7836(playerIn.field_6002, playerIn, hand);
            return class_1269.field_5812;
        }
        return super.method_7847(stack, playerIn, target, hand);
    }

    @Override
    public void method_7851(class_1799 itemStack, class_1792.class_9635 context, List<class_2561> tooltip, class_1836 tooltipFlag) {
        tooltip.add(class_2561.method_43471("tooltips.touhou_little_maid.camera.desc").method_27692(class_124.field_1077));
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.1-neo1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemCamera.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import com.github.tartaricacid.touhoulittlemaid.advancements.maid.TriggerType;
import com.github.tartaricacid.touhoulittlemaid.api.event.MaidAndItemTransformEvent;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.*;
import com.github.tartaricacid.touhoulittlemaid.util.MaidRayTraceHelper;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import net.minecraft.class_124;
import net.minecraft.class_1264;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1271;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_7923;
import net.minecraft.class_9279;

public class ItemCamera extends class_1792 {
    public ItemCamera() {
        super((new class_1793()).method_7889(1).method_7895(50));
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 worldIn, class_1657 playerIn, class_1268 handIn) {
        if (handIn == class_1268.field_5808) {
            int searchDistance = 8;
            class_1799 camera = playerIn.method_5998(handIn);
            Optional<EntityMaid> result = MaidRayTraceHelper.rayTraceMaid(playerIn, searchDistance);
            if (result.isPresent()) {
                EntityMaid maid = result.get();
                if (!worldIn.field_9236 && maid.method_5805() && maid.method_6171(playerIn) && !maid.method_6113()) {
                    spawnMaidPhoto(worldIn, maid, playerIn);
                    maid.method_31472();
                    playerIn.method_7357().method_7906(this, 20);
                    camera.method_7970(1, playerIn, class_1304.field_6173);
                    if (playerIn instanceof class_3222 serverPlayer) {
                        InitTrigger.MAID_EVENT.trigger(serverPlayer, TriggerType.PHOTO_MAID);
                    }
                }
                maid.spawnExplosionParticle();
                playerIn.method_5783(InitSounds.CAMERA_USE, 1.0f, 1.0f);
                return class_1271.method_29237(camera, worldIn.field_9236);
            }
        }
        return super.method_7836(worldIn, playerIn, handIn);
    }

    private void spawnMaidPhoto(class_1937 worldIn, EntityMaid maid, class_1657 playerIn) {
        class_1799 photo = InitItems.PHOTO.method_7854();
        class_2487 maidTag = new class_2487();
        maid.setHomeModeEnable(false);
        maid.method_5647(maidTag);
        maidTag.method_10582("id", Objects.requireNonNull(class_7923.field_41177.method_10221(InitEntities.MAID)).toString());

        var event = new MaidAndItemTransformEvent.ToItem(maid, photo, maidTag);
        MaidAndItemTransformEvent.TO_ITEM.invoker().onToItem(event);

        photo.method_57379(InitDataComponent.MAID_INFO, class_9279.method_57456(maidTag));
        class_1264.method_5449(worldIn, playerIn.method_23317(), playerIn.method_23318(), playerIn.method_23321(), photo);
    }

    @Override
    public class_1269 method_7847(class_1799 stack, class_1657 playerIn, class_1309 target, class_1268 hand) {
        // 返回 true，阻止打开女仆 GUI
        if (stack.method_7909() == this && target.method_5805() && target instanceof EntityMaid && ((EntityMaid) target).method_6171(playerIn)) {
            this.method_7836(playerIn.field_6002, playerIn, hand);
            return class_1269.field_5812;
        }
        return super.method_7847(stack, playerIn, target, hand);
    }

    @Override
    public void method_7851(class_1799 itemStack, class_1792.class_9635 context, List<class_2561> tooltip, class_1836 tooltipFlag) {
        tooltip.add(class_2561.method_43471("tooltips.touhou_little_maid.camera.desc").method_27692(class_124.field_1077));
    }
}
